@@ -12,6 +12,8 @@ CWD=$(pwd)
 TMPDIR=$(mktemp -d)
 cd "$TMPDIR"
 git clone https://dev.gajim.org/gajim/"$REPO".git
+( cd ./"$REPO"/"$PLUGIN"/;
+  dos2unix *.py *.ui *.ini )
 VERSION=$(grep ^version: ./"$REPO"/"$PLUGIN"/manifest.ini | sed 's/.*: *//')
 FILENAME="$CWD"/../"$PACKAGE"_"$VERSION".orig.tar.gz
 test ! -e "$FILENAME"
